
# Slot: minimum_node_type_id


The minimum node type ID to be used when using numeric node type IDs.

URI: [https://w3id.org/neat/ensmallenRunConfig__minimum_node_type_id](https://w3id.org/neat/ensmallenRunConfig__minimum_node_type_id)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Integer](types/Integer.md)

## Parents


## Children


## Used by

 * [EnsmallenRunConfig](EnsmallenRunConfig.md)
